<?php

namespace Drupal\wsolution_demo\Controller;

use Drupal\Core\Controller\ControllerBase;
use Drupal\Core\Entity\EntityTypeManagerInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Drupal\Core\Cache\CacheableJsonResponse;
use Drupal\Core\Cache\CacheableMetadata;

class Test extends ControllerBase {

  /**
   * Entity query factory.
   *
   * @var \Drupal\Core\Entity\Query\QueryFactory
   */
  protected $entityTypeManager;

  /**
   * Constructs a new CustomRestController object.
   *
   * @param \Drupal\Core\Entity\Query\QueryFactory $entityQuery
   * The entity query factory.
   */
  public function __construct(EntityTypeManagerInterface $entity_type_manager) {
    $this->entityTypeManager = $entity_type_manager;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('entity_type.manager')
    );
  }

  public function test403() {
    $url = "https://www.drupal.org/admin";
    $curl = curl_init();

    // Options
    curl_setopt($curl, CURLOPT_RETURNTRANSFER, 1);
    curl_setopt($curl, CURLOPT_URL, $url);

    // Execut
    $resp = curl_exec($curl);

    // Libération des ressources
    curl_close($curl);

    \Drupal::service('page_cache_kill_switch')->trigger();
    return [
      '#markup' => 'lol',
      '#cache' => ['max-age' => 0],
    ];
  }

  public function test404() {
    $url = "https://jeanmic.qsdsqdqsd/feeds/tag?tagnames=php&sort=newest";
    $curl = curl_init();

    // Options
    curl_setopt($curl, CURLOPT_RETURNTRANSFER, 1);
    curl_setopt($curl, CURLOPT_URL, $url);

    // Execut
    $resp = curl_exec($curl);

    // Libération des ressources
    curl_close($curl);

    \Drupal::service('page_cache_kill_switch')->trigger();
    return [
      '#markup' => 'lol',
      '#cache' => ['max-age' => 0],
    ];
  }

  public function test() {
    $url = "https://stackoverflow.com/feeds/tag?tagnames=php&sort=newest";
    $curl = curl_init();

    // Options
    curl_setopt($curl, CURLOPT_RETURNTRANSFER, 1);
    curl_setopt($curl, CURLOPT_URL, $url);

    // Execut
    $resp = curl_exec($curl);

    // Libération des ressources
    curl_close($curl);

    \Drupal::service('page_cache_kill_switch')->trigger();
    return [
      '#markup' => t('@url has been called',['@url' => $url]),
      '#cache' => ['max-age' => 0],
    ];
  }

  /**
   * Test rest controller.
   *
   * @return \Drupal\Core\Cache\CacheableJsonResponse
   * @throws \Drupal\Component\Plugin\Exception\InvalidPluginDefinitionException
   * @throws \Drupal\Component\Plugin\Exception\PluginNotFoundException
   */
  public function testRest() {

    // Initialize the response array.
    $response_array = [];

    // Load the 10 most recently updated nodes and build an array of titles to be
    // returned in the JSON response.
    // NOTE: Entity Queries will automatically honor site content permissions when
    // determining whether or not to return nodes. If this is not desired, adding
    // accessCheck(FALSE) to the query will bypass these permissions checks.
    // USE WITH CAUTION.
    $node_query = $this->entityTypeManager->getStorage('node')->getQuery()
      ->condition('status', 1)
      ->sort('changed', 'DESC')
      ->range(0, 10)
      ->execute();
    if ($node_query) {
      $nodes = $this->entityTypeManager()
        ->getStorage('node')
        ->loadMultiple($node_query);
      foreach ($nodes as $node) {
        $response_array[] = [
          'title' => $node->title->value,
        ];
      }
    }
    else {
      // Set the default response to be returned if no results can be found.
      $response_array = ['message' => 'No new nodes.'];
    }

    // Add the node_list cache tag so the endpoint results will update when nodes are
    // updated.
    $cache_metadata = new CacheableMetadata();
    $cache_metadata->setCacheTags(['node_list']);

    // Create the JSON response object and add the cache metadata.
    $response = new CacheableJsonResponse($response_array);
    $response
      ->addCacheableDependency((new CacheableMetadata())->setCacheMaxAge(0));

    return $response;
  }

}
