<?php

declare(strict_types=1);

namespace Drupal\wsolution_elastic\Entity;

use Drupal\Core\Config\Entity\ConfigEntityBase;
use Drupal\Core\Entity\Attribute\ConfigEntityType;
use Drupal\Core\Entity\EntityDeleteForm;
use Drupal\Core\StringTranslation\TranslatableMarkup;
use Drupal\wsolution_elastic\Form\WsolutionElasticForm;
use Drupal\wsolution_elastic\WsolutionElasticInterface;
use Drupal\wsolution_elastic\WsolutionElasticListBuilder;

/**
 * Defines the wsolution elastic entity type.
 */
#[ConfigEntityType(
  id: 'wsolution_elastic',
  label: new TranslatableMarkup('Wsolution elastic'),
  label_collection: new TranslatableMarkup('Wsolution elastics'),
  label_singular: new TranslatableMarkup('wsolution elastic'),
  label_plural: new TranslatableMarkup('wsolution elastics'),
  config_prefix: 'wsolution_elastic',
  entity_keys: [
    'id' => 'id',
    'label' => 'label',
    'uuid' => 'uuid',
  ],
  handlers: [
    'list_builder' => WsolutionElasticListBuilder::class,
    'form' => [
      'add' => WsolutionElasticForm::class,
      'edit' => WsolutionElasticForm::class,
      'delete' => EntityDeleteForm::class,
    ],
  ],
  links: [
    'collection' => '/admin/structure/wsolution-elastic',
    'add-form' => '/admin/structure/wsolution-elastic/add',
    'edit-form' => '/admin/structure/wsolution-elastic/{wsolution_elastic}',
    'delete-form' => '/admin/structure/wsolution-elastic/{wsolution_elastic}/delete',
  ],
  admin_permission: 'administer wsolution_elastic',
  label_count: [
    'singular' => '@count wsolution elastic',
    'plural' => '@count wsolution elastics',
  ],
  config_export: [
    'id',
    'label',
    'description',
    'elastic_cloud_id',
    'api_key_id',
    'api_key',
  ],
)]
final class WsolutionElastic extends ConfigEntityBase implements WsolutionElasticInterface {

  /**
   * The example ID.
   */
  protected string $id;

  /**
   * The example label.
   */
  protected string $label;

  /**
   * The example description.
   */
  protected string $description;
  protected string $elastic_cloud_id;
  protected string $api_key_id;
  protected string $api_key;

}
