<?php

namespace Drupal\wsolution_elastic\Form;

use Drupal\Core\Config\ConfigFactoryInterface;
use Drupal\Core\Entity\EntityTypeManagerInterface;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Logger\LoggerChannelTrait;
use Drupal\Core\Messenger\MessengerTrait;
use Drupal\elasticsearch_connector\ClusterManager;
use Drupal\elasticsearch_connector\ElasticSearch\ClientManagerInterface;
use Drupal\wsolution\Services\WSolutionInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 */
class InitIndexForm extends WSolutionSettingsForm {

  /**
   * Messenger trait.
   */
  use MessengerTrait;

  /**
   * Logger channel trait.
   */
  use LoggerChannelTrait;


  protected $entityTypeManager;

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return [
      'wsolution.index.settings',
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'wsolution_index_settings';
  }

  /**
   */
  public function __construct(ConfigFactoryInterface $config_factory, EntityTypeManagerInterface $entity_manager, ClientManagerInterface $client_manager, ClusterManager $cluster_manager, WSolutionInterface $wsolution_manager) {
    parent::__construct($config_factory);
    // Setup object members.
    $this->entityTypeManager = $entity_manager;
    $this->clientManager = $client_manager;
    $this->clusterManager = $cluster_manager;
    $this->wsolutionManager = $wsolution_manager;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('config.factory'),
      $container->get('entity_type.manager'),
      $container->get('elasticsearch_connector.client_manager'),
      $container->get('elasticsearch_connector.cluster_manager'),
      $container->get('wsolution.manager')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $indexs = $this->entityTypeManager->getStorage('elasticsearch_index')
      ->loadMultiple();
    foreach ($indexs as $index) {
      $options[$index->id()] = $index->name;
    }

    $config = $this->config('wsolution.index.settings');
    $form['index'] = [
      '#type' => 'select',
      '#required' => TRUE,
      '#options' => $options,
      '#title' => t('Index'),
      '#default_value' => $config->get('index') ?? '',
    ];
    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    parent::submitForm($form, $form_state);
    // Get mapping.
    $params_mapping = $this->wsolutionManager->getMapping();
    $params_index['index'] = $params_settings['index'] = $params_mapping['index'] = $form_state->getValue('index');
    $params_settings['body'] = [
      'number_of_shards' => 2,
      'number_of_replicas' => 1,

    ];
    /** @var  $index \Drupal\elasticsearch_connector\Entity\Index */
    $index = $this->entityTypeManager->getStorage('elasticsearch_index')
      ->load($form_state->getValue('index'));
    if (empty($index)) {
      $this->messenger()
        ->addMessage(t("Can't load index @index", ['@index' => $form_state->getValue('index')]));
      return FALSE;
    }
    /** @var  $cluster \Drupal\elasticsearch_connector\Entity\Cluster */
    $cluster = $this->entityTypeManager->getStorage('elasticsearch_cluster')
      ->load($index->get('server'));
    if (empty($cluster)) {
      $this->messenger()
        ->addMessage(t("Can't load cluster @cluster", ['@cluster' => $index->get('server')]));
    }
    $client = $this->clientManager->getClientForCluster($cluster);
    $mapping_es = $client->indices()->getMapping();
    $mapped = TRUE;
    // Load mapping and look if we got all mapped.
    if (!empty($mapping_es[$form_state->getValue('index')]['mappings']['properties'])) {
      foreach ($params_mapping['body'] as $key_mapping => $mapping_value) {
        if (!isset($mapping_es[$form_state->getValue('index')]['mappings']['properties'][$key_mapping])) {
          $mapped = FALSE;
          break;
        }
      }
    }
    // Update mapping.
    if ($mapped == FALSE) {
      $client->indices()->close($params_index);
      $client->indices()->putSettings($params_settings);
      $client->indices()->putMapping($params_mapping);
      $client->indices()->open($params_index);
      $this->messenger()->addMessage(t('Index updated'));
    }
  }

}
