<?php

namespace Drupal\wsolution_elastic\PasseplatElastic\StreamProcessor\SchemeProcessor\Task;

use Dakwamine\Component\Exception\UnmetDependencyException;
use Drupal\wsolution_elastic\PasseplatElastic\Service\DrupalElasticsearchService;
use Drupal\wsolution_elastic\PasseplatElastic\Definitions\AnalyzableContentIndexDef;
use Drupal\wsolution_elastic\PasseplatElastic\Definitions\ErrorsIndexDef;
use PassePlat\Logger\Elastic\Service\ElasticsearchService;
use PassePlat\Logger\Elastic\StreamProcessor\SchemeProcessor\Task\ElasticsearchLogger_0 as BaseLogger;

/**
 * Logger for Elasticsearch.
 *
 * This task handles the logging of analyzable content to Elasticsearch,
 * including error handling and schema validation.
 */
class ElasticsearchLogger_0 extends BaseLogger {

  /**
   * Initializes the Elasticsearch service.
   *
   * @return ElasticsearchService|null
   *
   * @throws UnmetDependencyException
   */
  protected function initializeElasticsearchService(): ?ElasticsearchService {
    /** @var ElasticsearchService $elasticSearchService */
    $elasticSearchService = $this->getComponentByClassName(DrupalElasticsearchService::class, TRUE);

    if ($elasticSearchService) {
      $this->elasticSearchService = $elasticSearchService;
    }

    return $elasticSearchService;
  }
  protected function logContent(array $contentToLog): array
  {
    $indexDef = new AnalyzableContentIndexDef();

    return $this->elasticSearchService->logItem(
      $indexDef,
      $contentToLog,
    );
  }
  protected function logErrors(array $errors, string $transactionId): void
  {
    if (!empty($errors)) {
      foreach ($errors as &$error) {
        $error['transaction_id'] = $transactionId;
      }

      $this->elasticSearchService->logBulk(new ErrorsIndexDef(), $errors);
    }
  }
}
