<?php

namespace Drupal\wsolution\Controller;

use Drupal\Core\Controller\ControllerBase;

use Dakwamine\Component\ComponentBasedObject;
use Drupal\Core\TempStore\PrivateTempStoreFactory;
use Drupal\wsolution\PasseplatForms\Handler\DashboardHandler;
use Drupal\wsolution\PasseplatForms\Handler\DumpHandler;
use Drupal\wsolution\PasseplatForms\Handler\ErrorsHandler;
use Drupal\wsolution\PasseplatForms\Handler\LogsDetailsHandler;
use Drupal\wsolution\PasseplatForms\Handler\LogsHandler;
use Drupal\wsolution\PasseplatForms\Handler\NavbarHandler;
use Drupal\wsolution\PasseplatForms\Handler\WebServiceEditHandler;
use Drupal\wsolution\PasseplatForms\Handler\WebServicesHandler;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Symfony\Component\HttpFoundation\JsonResponse;

class Admin extends ControllerBase {

  /**
   * @var \Drupal\Core\TempStore\PrivateTempStoreFactory
   */
  protected $privateTempStore;

  /**
   * ModalFormContactController constructor.
   *
   * @param \Drupal\Core\Form\FormBuilder $form_builder
   *   The form builder.
   */
  public function __construct(PrivateTempStoreFactory $private_temp_store) {
    $this->privateTempStore = $private_temp_store;
  }

  /**
   * {@inheritdoc}
   *
   * @param \Symfony\Component\DependencyInjection\ContainerInterface $container
   *   The Drupal service container.
   *
   * @return static
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('tempstore.private')
    );
  }

  /**
   * Callback route passeplat.
   *
   * @return array
   *   The render array.
   */
  public function page(string $page) {
    // @todo find better way to get available routes?
    $available_route = [
      'navbar',
      'dashboard',
      'errors',
      'logs',
      'logs-details',
      'navbar',
      'webservice-edit',
      'webservices',
    ];
    if (!in_array($page, $available_route, TRUE)) {
      $page = 'dashboard';
    }
    $active_tab = $page;
    switch ($page) {
      case     'webservice-edit':
        $active_tab = 'edit';
        break;
      case     'webservices':
        $active_tab = 'list';
        break;
    }
    $wsid = \Drupal::request()->query->get('wsid') ?? NULL;
    $render['nav'] = [
      '#theme' => 'wsolution_html_builder',
      '#data_url' => '/admin/structure/wsolution/handler/navbar?wsid=' . $wsid . '&activeTab=' . $active_tab,
      '#attached' => [
        'library' => [
          'wsolution/wsolution',
        ],
      ],
    ];
    $render['page'] = [
      '#theme' => 'wsolution_html_builder',
      '#data_url' => '/admin/structure/wsolution/handler/' . $page . '?wsid=' . $wsid,
      '#attached' => [
        'library' => [
          'wsolution/wsolution',
        ],
      ],
    ];
    return $render;
  }

  /**
   * Returns a page title.
   */
  public function titleHandler($page) {
    return t('Wsolution @title', ['@title' => $page]);
  }

  /**
   * Callback json handler.
   *
   * @param string $class
   *
   * @return \Symfony\Component\HttpFoundation\JsonResponse
   * @throws \Dakwamine\Component\Exception\UnmetDependencyException
   */
  public function handler(string $class) {
    switch ($class) {
      case 'navbar':
        $class_name = NavbarHandler::class;
        $temp_store_key = NavbarHandler::TEMP_STORE_KEY;
        break;
      case 'dashboard':
        $class_name = DashboardHandler::class;
        $temp_store_key = DashboardHandler::TEMP_STORE_KEY;
        break;
      case 'dump':
        $class_name = DumpHandler::class;
        $temp_store_key = DumpHandler::TEMP_STORE_KEY;
        break;
      case 'errors':
        $class_name = ErrorsHandler::class;
        $temp_store_key = ErrorsHandler::TEMP_STORE_KEY;
        break;
      case 'logs-details':
        $class_name = LogsDetailsHandler::class;
        $temp_store_key = LogsDetailsHandler::TEMP_STORE_KEY;
        break;
      case 'logs':
        $class_name = LogsHandler::class;
        $temp_store_key = LogsHandler::TEMP_STORE_KEY;
        break;
      case 'webservices':
        $class_name = WebServicesHandler::class;
        $temp_store_key = WebServicesHandler::TEMP_STORE_KEY;
        break;
      case 'webservice-edit':

        $class_name = WebServiceEditHandler::class;
        $temp_store_key = WebServiceEditHandler::TEMP_STORE_KEY;
        break;
    }
    if (!empty($temp_store_key) && !empty($class_name)) {
      /** @var  $handler */
      $handler = ComponentBasedObject::getRootComponentByClassName(
        $class_name,
        TRUE
      );
      $handler->handleRequest();

      $tempstore = $this->privateTempStore->get('wsolution');
      $yaml = $tempstore->get($temp_store_key);

      return new JsonResponse($yaml);
    }
    return new JsonResponse(NULL);
  }

}
