<?php

declare(strict_types=1);

namespace Drupal\wsolution\Entity;

use Drupal\Core\Config\Entity\ConfigEntityBase;
use Drupal\Core\Entity\Attribute\ConfigEntityType;
use Drupal\Core\Entity\EntityDeleteForm;
use Drupal\Core\StringTranslation\TranslatableMarkup;
use Drupal\wsolution\Form\WsolutionUserForm;
use Drupal\wsolution\WsolutionUserInterface;
use Drupal\wsolution\WsolutionUserListBuilder;

/**
 * Defines the wsolution user entity type.
 */
#[ConfigEntityType(
  id: 'wsolution_user',
  label: new TranslatableMarkup('WSolution user'),
  label_collection: new TranslatableMarkup('WSolution users'),
  label_singular: new TranslatableMarkup('wsolution user'),
  label_plural: new TranslatableMarkup('wsolution users'),
  config_prefix: 'wsolution_user',
  entity_keys: [
    'id' => 'id',
    'label' => 'label',
    'uuid' => 'uuid',
  ],
  handlers: [
    'list_builder' => WsolutionUserListBuilder::class,
    'form' => [
      'add' => WsolutionUserForm::class,
      'edit' => WsolutionUserForm::class,
      'delete' => EntityDeleteForm::class,
    ],
  ],
  links: [
    'collection' => '/admin/structure/wsolution-user',
    'add-form' => '/admin/structure/wsolution-user/add',
    'edit-form' => '/admin/structure/wsolution-user/{wsolution_user}',
    'delete-form' => '/admin/structure/wsolution-user/{wsolution_user}/delete',
  ],
  admin_permission: 'administer wsolution_user',
  label_count: [
    'singular' => '@count wsolution user',
    'plural' => '@count wsolution users',
  ],
  config_export: [
    'id',
    'label',
    'description',
    'token',
  ],
)]
final class WsolutionUser extends ConfigEntityBase implements WsolutionUserInterface {

  /**
   * The example ID.
   */
  protected string $id;

  /**
   * The example label.
   */
  protected string $label;

  /**
   * The example description.
   */
  protected string $description;
  protected string $token;

}
