<?php

declare(strict_types=1);

namespace Drupal\wsolution\Entity;

use Drupal\Core\Config\Entity\ConfigEntityBase;
use Drupal\Core\Entity\Attribute\ConfigEntityType;
use Drupal\Core\Entity\EntityDeleteForm;
use Drupal\Core\StringTranslation\TranslatableMarkup;
use Drupal\wsolution\Form\WsolutionWebserviceForm;
use Drupal\wsolution\WsolutionWebserviceInterface;
use Drupal\wsolution\WsolutionWebserviceListBuilder;

/**
 * Defines the wsolution webservice entity type.
 */
#[ConfigEntityType(
  id: 'wsolution_webservice',
  label: new TranslatableMarkup('WSolution Webservice'),
  label_collection: new TranslatableMarkup('WSolution Webservices'),
  label_singular: new TranslatableMarkup('wsolution webservice'),
  label_plural: new TranslatableMarkup('wsolution webservices'),
  config_prefix: 'wsolution_webservice',
  entity_keys: [
    'id' => 'id',
    'label' => 'label',
    'uuid' => 'uuid',
  ],
  handlers: [
    'list_builder' => WsolutionWebserviceListBuilder::class,
    'form' => [
      'add' => WsolutionWebserviceForm::class,
      'edit' => WsolutionWebserviceForm::class,
      'delete' => EntityDeleteForm::class,
    ],
  ],
  links: [
    'collection' => '/admin/structure/wsolution-webservice',
    'add-form' => '/admin/structure/wsolution-webservice/add',
    'edit-form' => '/admin/structure/wsolution-webservice/{wsolution_webservice}',
    'delete-form' => '/admin/structure/wsolution-webservice/{wsolution_webservice}/delete',
  ],
  admin_permission: 'administer wsolution_webservice',
  label_count: [
    'singular' => '@count wsolution webservice',
    'plural' => '@count wsolution webservices',
  ],
  config_export: [
    'id',
    'domain',
    'label',
    'description',
    'tasks',
    'wsuid'
  ],
)]
final class WsolutionWebservice extends ConfigEntityBase implements WsolutionWebserviceInterface {

  /**
   * The wsolution webservice ID.
   */
  protected string $id;

  protected string $domain;

  /**
   * The example label.
   */
  protected string $label;

  /**
   * The example description.
   */
  protected string $description;
  protected string $wsuid;

  protected array $tasks = [];

  /**
   * {@inheritdoc}
   */
  public function getTasks(): array {
    return $this->tasks;
  }

  /**
   * {@inheritdoc}
   */
  public function setTasks(array $tasks): WsolutionWebservice {
    $this->tasks = $tasks;
    return $this;
  }

}
