<?php

namespace Drupal\wsolution\Form;

use Drupal\Core\Form\FormStateInterface;

/**
 * Class ProductPageForm.
 */
class OutgoingSettingsForm extends WSolutionSettingsForm {

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return [
      'wsolution.outgoing.settings',
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'wsolution_outgoing_settings';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $config = $this->config('wsolution.outgoing.settings');
    $form['passeplat_mode'] = [
      '#type' => 'radios',
      '#required' => TRUE,
      '#title' => $this->t('Passeplat mode'),
      '#options' => [
        'sass' => $this->t('Passeplat SASS'),
        'internal' => $this->t('Passeplat Internal'),
      ],
      '#default_value' => $config->get('passeplat_mode'),
    ];
    $form['domain_ws'] = [
      '#type' => 'textfield',
      '#required' => TRUE,
      '#default_value' => $config->get('domain_ws') ?? '.wsolution.app',
      '#title' => t('Passeplat host'),
      '#states' => [
        'visible' => [
          ':input[name="passeplat_mode"]' => ['value' => 'sass'],
        ],
      ],
    ];
    // Onglet 'WSID WS'
    $form['wsidws']['wsid'] = [
      '#type' => 'textfield',
      '#title' => $this->t('WSolution identifier'),
      '#description' =>$this->t('Visit the site where you put your wsolution app to create your account then copy your uuid on the account edit page.'),
      '#default_value' => $config->get('wsid'),
      '#states' => [
        'visible' => [
          ':input[name="passeplat_mode"]' => ['value' => 'sass'],
        ],
      ],
    ];

    // Onglet 'Pattern URL'
    $form['rest_url']['mode'] = [
      '#type' => 'radios',
      '#title' => $this->t('Mode'),
      '#options' => [
        'include' => $this->t('Include'),
        'exclude' => $this->t('Exclude'),
      ],
      '#default_value' => $config->get('mode'),
      '#states' => [
        'visible' => [
          ':input[name="passeplat_mode"]' => ['value' => 'sass'],
        ],
      ],
    ];
    $form['rest_url']['rest_url'] = [
      '#type' => 'textarea',
      '#title' => t('Rest URLs'),
      '#description' => t('Handle all rest request by matching url. One url per line.'),
      '#default_value' => $config->get('rest_url'),
      '#states' => [
        'visible' => [
          ':input[name="passeplat_mode"]' => ['value' => 'sass'],
        ],
      ],
    ];
    $form['library'] = [
      '#type' => 'checkboxes',
      '#title' => t('Library Hooks'),
      '#description' => t('Library hooks allow PHP-VCR to intercept HTTP requests by overwriting the libraries method to issue requests0'),
      '#default_value' => $config->get('library') ?? [
          'curl',
          'soap',
          'stream_wrapper',
        ],
      '#options' => [
        'curl' => t('Curl'),
        'soap' => t('Soap'),
        'stream_wrapper' => t('Stream wrapper'),
      ],
    ];

    $form['file_path'] = [
      '#type' => 'textfield',
      '#required' => TRUE,
      '#title' => t('Log storage'),
      '#description' => t('Select the storage mode for logging.'),
      '#default_value' => $config->get('file_path') ?? '/sites/default/files',
      '#states' => [
        'invisible' => [
          ':input[name="storage"]' => ['value' => 'ws_es'],
        ],
        'optional' => [
          ':input[name="storage"]' => ['value' => 'ws_es'],
        ],
      ],
    ];
    return parent::buildForm($form, $form_state);
  }

}
