<?php

namespace Drupal\wsolution\Passeplat\Config;

use Dakwamine\Component\Event\EventInterface;
use Dakwamine\Component\Exception\UnmetDependencyException;
use Drupal\wsolution\Passeplat\Config\ConfigItem\UserConfigItem;
use Drupal\wsolution\Passeplat\Config\ConfigItem\WebServiceConfigItem;
use Drupal\wsolution\Passeplat\User\UserManager;
use PassePlat\Core\Config\ConfigItem\ConfigItem;
use PassePlat\Core\Config\Configuration as PassePlatConfig;
use PassePlat\Core\Config\Event\GetEnabledConfigItemEvent;
use PassePlat\Core\Exception\ConfigException;
use Drupal\wsolution\Passeplat\Webservice\WebServiceManager;

/**
 * Main configuration loader for passeplat.
 */
class Configuration extends PassePlatConfig {

  /**
   * Gets the default list of config item names.
   *
   * @return string[]
   *   Array of default config item names.
   */
  protected function getDefaultConfigItemNames(): array {
    return [
      //  TrustedHostPatternConfigItem::class,
      UserConfigItem::class,
      WebServiceConfigItem::class,
    ];
  }

  public function handleEvent(EventInterface $event): void {
    if ($event->getName() !== GetEnabledConfigItemEvent::EVENT_NAME) {
      return;
    }

    // Remove parent config item.
    $parent_config = parent::getDefaultConfigItemNames();
    foreach ($parent_config as $configItemName) {
      /** @var GetEnabledConfigItemEvent $event */
      $event->removeConfigItem($configItemName);
    }
    $configItemNames = $this->getDefaultConfigItemNames();
    foreach ($configItemNames as $configItemName) {
      /** @var GetEnabledConfigItemEvent $event */
      $event->registerConfigItem($configItemName);
    }
  }

  /**
   * Initialize the configuration.
   *
   * @param string $configurationDirectoryBasePath
   *   Configuration local file path.
   *
   * @throws ConfigException
   */
  public function initializeConfiguration($configurationDirectoryBasePath): void {
    // Initialize live configuration from files.
    // $values = $this->configLoader->loadConfigFromDirectory($configurationDirectoryBasePath);

    try {
      // Get enabled configuration items.
      $enabledConfigItems = $this->getEnabledConfigItems();
    }
    catch (UnmetDependencyException $e) {
      throw new ConfigException('Error on retrieving enabled ConfigItem instances.', $e);
    }
    foreach ($enabledConfigItems as $configItem) {

      if($configItem instanceof ConfigItem) {

        $values['repository']['type'] = $this->getRepositoryConfig($configItem);
        // We only set enabled configurations.
        $configItem->setValues($values);
      }
    }
  }
  private function getRepositoryConfig(ConfigItem  $configItem){
    if($configItem instanceof UserConfigItem) {
      return UserManager::REPOSITORY_TYPE__DRUPAL_CONFIG;

    }    if($configItem instanceof WebServiceConfigItem) {
      return WebServiceManager::REPOSITORY_TYPE__DRUPAL_CONFIG;

    }

  }

}
