<?php

namespace Drupal\wsolution\Passeplat;

use Dakwamine\Component\Event\ListenerProvider;
use Dakwamine\Component\RootDependencyDefinition;
use PassePlat\App\EventListenerDefinition;
use PassePlat\App\PassePlat as MainPasseplat;
use PassePlat\Core\AnalyzableContent\AnalyzableContent;
use Drupal\wsolution\Passeplat\Config\Configuration;
use PassePlat\Core\Config\Event\GetEnabledConfigItemEvent;
use PassePlat\Core\Exception\ConfigException;
use PassePlat\Core\PassePlatResponseFactory;
use PassePlat\Core\StreamProcessor\SchemeProcessor\Event\ProcessSchemeEvent;
use PassePlat\Core\StreamProcessor\SchemeProcessor\HttpSchemeProcessor;
use Drupal\wsolution\Passeplat\StreamProcessor\StreamProcessor;
use PassePlat\Ftp\StreamProcessor\SchemeProcessor\FtpSchemeProcessor;
use Drupal\wsolution_elastic\PasseplatElastic\StreamProcessor\SchemeProcessor\Task\ElasticsearchLogger_0;

/**
 * Main entry point for passeplat app.
 */
class Passeplat extends MainPasseplat {
  public function getDependencyDefinitions(): array {
    $definitions = parent::getDependencyDefinitions();
    $definitions[] = new RootDependencyDefinition(AnalyzableContent::class, $this->analyzableContent);
    $definitions[] = new RootDependencyDefinition(Configuration::class, $this->configuration);
    $definitions[] = new RootDependencyDefinition(ListenerProvider::class, $this->listenerProvider);
    $definitions[] = new RootDependencyDefinition(PassePlatResponseFactory::class, $this->passePlatResponseFactory);
    $definitions[] = new RootDependencyDefinition(StreamProcessor::class, $this->streamProcessor);
    return $definitions;
  }
  protected function onReady(): void {
    $this->registerEventListeners([
      new EventListenerDefinition(
        ProcessSchemeEvent::EVENT_NAME,
        HttpSchemeProcessor::class
      ),
      new EventListenerDefinition(
        GetEnabledConfigItemEvent::EVENT_NAME,
        Configuration::class
      ),
    ]);
    $moduleHandler = \Drupal::service('module_handler');
    if ($moduleHandler->moduleExists('wsolution_elastic')) {
      // Register elastic logger event.
      // @todo maybe try to external this.
      $this->registerEventListeners([
        new EventListenerDefinition(
          GetEnabledConfigItemEvent::EVENT_NAME,
          ElasticsearchLogger_0::class
        ),
      ]);

    }

    $this->registerEventListeners([
      new EventListenerDefinition(
        ProcessSchemeEvent::EVENT_NAME,
        FtpSchemeProcessor::class
      ),
    ]);

  }
  /**
   * Loads the main configuration.
   *
   * @throws ConfigException
   */
  public function loadConfiguration(): void {
    $this->configuration->initializeConfiguration(NULL);
  }
}
