<?php

namespace Drupal\wsolution\Passeplat\User\Repository;

use Dakwamine\Component\RootDependencyDefinition;
use Drupal\wsolution\Entity\WsolutionUser;
use PassePlat\Core\Config\ConfigLoader;
use PassePlat\Core\Exception\ConfigException;
use PassePlat\Core\Exception\ErrorCode;
use PassePlat\Core\Exception\UserRepositoryException;
use PassePlat\Core\User\Repository\UserRepository;

/**
 * Local config user repository.
 *
 * Not the most efficient repository for large user bases.
 * Useful when a database is not available and when only few users exist.
 */
class DrupalConfigUserRepository extends UserRepository {

  /**
   * Config loader.
   *
   * @var ConfigLoader
   */
  private $configLoader;

  /**
   * User definitions.
   *
   * @var array
   */
  private $definitions = [];

  /**
   * Tells if definitions were loaded.
   *
   * @var bool
   */
  private $hasLoaded = FALSE;

  public function authenticateUser($uid, $token): bool {
    if (empty($uid)) {
      return FALSE;
    }

    try {
      /** @var  $passeplat_user \Drupal\wsolution\Entity\WsolutionUser */
      // Try to load config entity user.
      $passeplat_user = \Drupal::entityTypeManager()
        ->getStorage('wsolution_user')
        ->load($uid);
      if (empty($passeplat_user) || !$passeplat_user instanceof WsolutionUser) {
        return FALSE;
      }
      $config_token = $passeplat_user->get('token');
      if (empty($config_token)) {
        return TRUE;
      }
      if (!empty($config_token) && $config_token == $token) {
        return TRUE;
      }
      return FALSE;
    }
    catch (ConfigException $exception) {
      // Do as no user was found.
      return FALSE;
    }

    return FALSE;
  }

  public function getDependencyDefinitions(): array {
    $definitions = parent::getDependencyDefinitions();
    $definitions[] = new RootDependencyDefinition(ConfigLoader::class, $this->configLoader);
    return $definitions;
  }

  /**
   * Gets the users definitions.
   *
   * @throws ConfigException
   *   Config error.
   */
  private function getDefinitions(): array {
    if (!$this->hasLoaded) {
      $this->definitions = \Drupal::entityTypeManager()
        ->getStorage('wsolution_user')
        ->loadMultiple();
      $this->hasLoaded = TRUE;
    }

    return $this->definitions;
  }

  public function hasUsers(): bool {
    try {
      return !empty($this->getDefinitions());
    }
    catch (ConfigException $exception) {
      throw new UserRepositoryException('Could not load the users.', $exception, ErrorCode::PP_USER, 0);
    }
  }

}
