<?php

namespace Drupal\wsolution\Passeplat\User;

use Drupal\wsolution\Passeplat\User\Repository\DrupalConfigUserRepository;
use PassePlat\Core\Exception\UserException;
use PassePlat\Core\Exception\UserRepositoryException;
use PassePlat\Core\User\UserManager as CoreUserManager;
use Dakwamine\Component\Exception\UnmetDependencyException;

class UserManager extends CoreUserManager {

  const REPOSITORY_TYPE__DRUPAL_CONFIG = 'REPOSITORY_TYPE__DRUPAL_CONFIG';

  protected function getAllowedRepositoryTypes() {
    return [
      DrupalConfigUserRepository::class => static::REPOSITORY_TYPE__DRUPAL_CONFIG,
    ];
  }

  public function setRepositoryType(string $repositoryType): void {
    $repositoryClass = '';

    foreach ($this->getAllowedRepositoryTypes() as $className => $type) {
      if ($repositoryType === $type) {
        $repositoryClass = $className;
        break;
      }
    }
    if (empty($repositoryClass)) {
      throw new UserRepositoryException(
        'Invalid user repository type.'
      );
    }

    if ($this->currentRepositoryType === $repositoryType) {
      // Already loaded.
      return;
    }

    // Remove current repository (if any).
    $this->removeComponentsByClassName(DrupalConfigUserRepository::class);

    try {
      // Append new repository. This is expected to work without failure.
      $this->userRepository = $this->addComponentByClassName($repositoryClass);
    }
    catch (UnmetDependencyException $e) {
      throw new UserException('Could not load user repository component.', $e);
    }

    // Changed current repository type.
    $this->currentRepositoryType = $repositoryType;
  }

}
