<?php

namespace Drupal\wsolution\Passeplat\Webservice\Repository;

use Dakwamine\Component\RootDependencyDefinition;
use PassePlat\Core\Config\ConfigLoader;
use PassePlat\Core\Exception\ConfigException;
use PassePlat\Core\WebService\Repository\WebServiceRepository;

/**
 * Local config user repository.
 *
 * Not the most efficient repository for large user bases.
 * Useful when a database is not available and when only few users exist.
 */
class DrupalConfigWebServiceRepository extends WebServiceRepository {

  /**
   * Config loader.
   *
   * @var ConfigLoader
   */
  private $configLoader;

  /**
   * User definitions.
   *
   * @var array
   */
  private $definitions = [];

  /**
   * Tells if definitions were loaded.
   *
   * @var bool
   */
  private $hasLoaded = FALSE;

  public function getDependencyDefinitions(): array {
    $definitions = parent::getDependencyDefinitions();
    $definitions[] = new RootDependencyDefinition(ConfigLoader::class, $this->configLoader);
    return $definitions;
  }

  /**
   * Loads the config file for the web service identified by the given
   * arguments.
   *
   * @param string $webServiceId
   *   ID of the web service.
   * @param string $userId
   *   ID of the user who attempts to use the web service.
   *
   * @return array
   *   Array of data.
   *
   * @throws UnmetDependencyException
   * @throws ConfigException
   */
  public function loadWebServiceConfigFromFileSystem(string $webServiceId, string $userId): array {
    /** @var ConfigLoader $configLoader */
    //   $configLoader = $this->getComponentByClassName(ConfigLoader::class, TRUE);

    // Load webservice-specific config.
    //   $configs = $configLoader->loadConfigFromDirectory('config/app/webservice', $webServiceId);

    //@todo find a way to reverse the webserviceID to real host without wsuser id.
    $wsoution_manager = \Drupal::service('wsolution.manager');
    $domain = $wsoution_manager->transformWsidToDomain($webServiceId, $userId);

    /** @var  $configs  \Drupal\wsolution\Entity\WsolutionWebservice[] */
    $configs = \Drupal::entityTypeManager()
      ->getStorage('wsolution_webservice')
      ->loadByProperties(['domain' => $domain]);

    if (!empty($configs)) {
      $config = reset($configs);
      return $config->toArray();
    }
    /*
        // Load the default user config.
        $userConfig = $configLoader->loadConfigFromDirectory('config/app/webservice', $userId);

        if (!empty($userConfig[$userId])) {
          return $userConfig[$userId];
        }

        // Load the application wide default config.
        $userConfig = $configLoader->loadConfigFromDirectory('config/app/webservice', 'default');

        if (!empty($userConfig['default'])) {
          return $userConfig['default'];
        }*/

    return [];
  }

}
