<?php

namespace Drupal\wsolution\Passeplat\Webservice;

use Dakwamine\Component\RootDependencyDefinition;
use Drupal\wsolution\Passeplat\User\Repository\DrupalConfigUserRepository;
use Drupal\wsolution\Passeplat\Webservice\Repository\DrupalConfigWebServiceRepository;
use PassePlat\Core\Exception\UserException;
use Dakwamine\Component\Exception\UnmetDependencyException;
use PassePlat\Core\Exception\WebServiceException;
use Drupal\wsolution\Passeplat\Security\HostChecker;
use Drupal\wsolution\Passeplat\User\Authenticator\Authenticator;
use Drupal\wsolution\Passeplat\User\UserManager;
use PassePlat\Core\WebService\WebServiceManager as CoreWebServiceManager;

class WebServiceManager extends CoreWebServiceManager {

  const REPOSITORY_TYPE__DRUPAL_CONFIG = 'REPOSITORY_TYPE__DRUPAL_CONFIG';
  public function getDependencyDefinitions(): array
  {
    $definitions = parent::getDependencyDefinitions();
    $definitions[] = new RootDependencyDefinition(Authenticator::class, $this->authenticator);
    $definitions[] = new RootDependencyDefinition(HostChecker::class, $this->hostChecker);
    $definitions[] = new RootDependencyDefinition(UserManager::class, $this->userManager);
    return $definitions;
  }
  protected function getAllowedRepositoryTypes() {
    return [
      DrupalConfigWebServiceRepository::class => static::REPOSITORY_TYPE__DRUPAL_CONFIG,
    ];
  }

  public function setRepositoryType(string $repositoryType): void {
    $repositoryClass = '';

    foreach ($this->getAllowedRepositoryTypes() as $className => $type) {
      if ($repositoryType === $type) {
        $repositoryClass = $className;
        break;
      }
    }
    if (empty($repositoryClass)) {
      throw new WebServiceException(
        'Invalid webservice repository type.'
      );
    }

    if ($this->currentRepositoryType === $repositoryType) {
      // Already loaded.
      return;
    }

    // Remove current repository (if any).
    $this->removeComponentsByClassName(DrupalConfigUserRepository::class);

    try {
      // Append new repository. This is expected to work without failure.
      $this->webserviceRepository = $this->addComponentByClassName($repositoryClass);
    }
    catch (UnmetDependencyException $e) {
      throw new UserException('Could not load user repository component.', $e);
    }

    // Changed current repository type.
    $this->currentRepositoryType = $repositoryType;
  }

}
