<?php

namespace Drupal\wsolution\PasseplatForms\Handler;

use Dakwamine\Component\ComponentBasedObject;
use PassePlat\Forms\Vue\Response;
use Drupal\wsolution_elastic\PasseplatElastic\Definitions\AnalyzableContentIndexDef;
use Drupal\wsolution_elastic\PasseplatElastic\Definitions\ErrorsIndexDef;
use Drupal\wsolution_elastic\PasseplatElastic\Service\DrupalElasticsearchService;
use PassePlat\Forms\Handler\DashboardHandler as BaseDashboardHandler;

/**
 * Provides methods for performing specific operations related to dashboard
 * page.
 */
class DashboardHandler extends BaseDashboardHandler {

  public const string TEMP_STORE_KEY = 'dashboard';

  use HandlerTrait;

  public function handlePostRequest(): void {
    try {
      $fullYamlServer = $this->getBlueprint('dashboard');
      //   $clientInput = json_decode(file_get_contents('php://input'), TRUE);

      $data = $fullYamlServer['data'];
      $clientInput = $this->getPhpInput();
      if (!empty($clientInput['data'])) {
        // The user clicked on the button.
        $data = $clientInput['data'];
      }

      // The user clicked on the button.
      $data['wsid'] = \Drupal::request()->query->get('wsid') ?? NULL;

      $endDate = !empty($data['endDateFilter']) ? strtotime($data['endDateFilter']) : time();
      $startDate = !empty($data['startDateFilter']) ? strtotime($data['startDateFilter']) : 0;

      $query = $this->buildQuery($data['wsid'], $endDate, $startDate);

      /** @var \PassePlat\Logger\Elastic\Service\ElasticsearchService $elasticSearchServer */
      $elasticSearchService = ComponentBasedObject::getRootComponentByClassName(
        DrupalElasticsearchService::class,
        TRUE
      );

      /** @var ErrorsIndexDef $AnalyzableContentIndex */
      $errorsIndexDef = ComponentBasedObject::getRootComponentByClassName(ErrorsIndexDef::class, TRUE);

      $analyzableContentIndexDef = ComponentBasedObject::getRootComponentByClassName(
        AnalyzableContentIndexDef::class,
        TRUE
      );

      $response = $elasticSearchService->search($errorsIndexDef, $query);

      $stats = $this->getBucketCount($response['aggregations']);

      $data['totalValidationErrors'] = $stats['totalErrors'];

      $data['errorTypesChart']['datasets'][0]['data'] = [
        $stats['requestErrors'],
        $stats['responseErrors'],
      ];

      $data['errorCategoriesChart']['datasets'][0]['data'] = [
        $stats['parsingErrors'],
        $stats['schemaErrors'],
        $stats['valueErrors'],
      ];

      $data['errorItemsChart']['datasets'][0]['data'] = [
        $stats['bodyErrors'],
        $stats['cookiesErrors'],
        $stats['headersErrors'],
        $stats['pathErrors'],
        $stats['queryErrors'],
        $stats['securityErrors'],
      ];

      $interval = $this->getOptimalInterval($startDate, $endDate);

      try {
        // History Lines:
        $historyQuery = $this->buildHistoryQuery($data['wsid'], $endDate, $startDate, $interval);

        $performanceResponse = $elasticSearchService->search($analyzableContentIndexDef, $historyQuery);

        $this->getHistoryData($performanceResponse['aggregations'], $data['historyChart']);
      }
      catch (\Exception $e) {
        $data['historyChart'] = '';
      }

      try {
        // Performance Lines:
        $performanceQuery = $this->buildPerformanceQuery(
          $data['wsid'],
          $endDate,
          $startDate,
          $interval
        );

        $performanceResponse = $elasticSearchService->search($analyzableContentIndexDef, $performanceQuery);

        $this->getPerformanceData($performanceResponse['aggregations'], $data['performanceChart']);
      }
      catch (\Exception $e) {
        $data['performanceChart'] = '';
      }

      $output = $fullYamlServer;
      $output['data'] = $data;
      $tempStoreFactory = \Drupal::service('tempstore.private');

      $tempstore = $tempStoreFactory->get('wsolution');

      $tempstore->set(self::TEMP_STORE_KEY, $output);
      //  Response::sendOk($output);
    }
    catch (\Exception $e) {
      Response::sendInternalServerError();
    }
  }

}
