<?php

namespace Drupal\wsolution\PasseplatForms\Handler;

use Dakwamine\Component\ComponentBasedObject;
use Dakwamine\Component\Exception\UnmetDependencyException;
use PassePlat\Core\Exception\Exception;
use Drupal\wsolution_elastic\PasseplatElastic\Definitions\ErrorsIndexDef;
use PassePlat\Logger\Elastic\Exception\CouldNotCreateElasticsearchIndexException;
use PassePlat\Logger\Elastic\Exception\CouldNotLoadElasticsearchIndexException;
use PassePlat\Logger\Elastic\Exception\ElasticsearchException;
use Drupal\wsolution_elastic\PasseplatElastic\Service\DrupalElasticsearchService;
use PassePlat\Forms\Handler\DumpHandler as BaseDumpHandler;

/**
 * This file should only exist in development and testing environments.
 * It must NEVER be used in production.
 */

/**
 * For generating and logging dump OpenAPI validation errors:
 *
 * - Set the ERROR_COUNT constant to define the number of documents in
 * Elasticsearch, where each document corresponds to a validation error.
 * - Then, run the script by calling localhost/dump.php.
 */

/**
 * Handles requests corresponding to 'forms/dump.php'.
 * This class is responsible for generating and logging dump validation errors.
 */
class DumpHandler extends BaseDumpHandler {

  public const string TEMP_STORE_KEY = 'dump';
  /**
   * Processes the POST request for 'charts/dump.php'.
   *
   * Generates random validation errors and logs them to Elasticsearch.
   *
   * @throws CouldNotCreateElasticsearchIndexException
   *   If the Elasticsearch index cannot be created.
   * @throws CouldNotLoadElasticsearchIndexException
   *   If the Elasticsearch index cannot be loaded.
   * @throws ElasticsearchException
   *   If an error occurs while logging to Elasticsearch.
   * @throws UnmetDependencyException|Exception
   *   If a required component cannot be created.
   * @throws \Random\RandomException
   *   Thrown if an error occurs while generating random validation errors.
   */
  public function handlePostRequest(): void {
    $dumpErrorsToLog = $this->generateLoggableDumpErrors([
      'webServiceId' => '',
      'userId' => '',
    ], 0);

    /** @var \PassePlat\Logger\Elastic\Service\ElasticsearchService $elasticSearchServer */
    $elasticSearchServer = ComponentBasedObject::getRootComponentByClassName(DrupalElasticsearchService::class, TRUE);

    /** @var ErrorsIndexDef $errorIndex */
    $errorIndex = ComponentBasedObject::getRootComponentByClassName(ErrorsIndexDef::class, TRUE);

    $response = $elasticSearchServer->logBulk($errorIndex, $dumpErrorsToLog);
    $tempStoreFactory = \Drupal::service('tempstore.private');

    $tempstore = $tempStoreFactory->get('wsolution');

    $tempstore->set(self::TEMP_STORE_KEY, $response);
    //    Response::sendOk($response);
  }

}
