<?php

namespace Drupal\wsolution\PasseplatForms\Handler;

use Dakwamine\Component\ComponentBasedObject;
use PassePlat\Forms\Vue\Response;
use PassePlat\Logger\Elastic\Definitions\ErrorsIndexDef;
use PassePlat\Logger\Elastic\Service\ElasticsearchService;
use PassePlat\Forms\Handler\ErrorsHandler as BaseErrorsHandler;

class ErrorsHandler extends BaseErrorsHandler {

  public const string TEMP_STORE_KEY = 'errors';
  use HandlerTrait;

  public function handlePostRequest(): void {
    try {
      // Get the absolute path of the YAML file.
      $fullYamlServer = $this->getBlueprint('errors');

      // Retrieve and decode the JSON input from the request body.
      // Retrieve post data.
      $data = $fullYamlServer['data'];
      $clientInput = $this->getPhpInput();
      if (!empty($clientInput['data'])) {
        // The user clicked on the button.
        $data = $clientInput['data'];
      }
      $data['filters']['webServiceId'] = \Drupal::request()->query->get('wsid') ?? NULL;

      // Set the filters, sorts, pagination parameters (from and size), or default values if not provided.
      $filters = $data['filters'];
      $sorts = $data['sorts'] ?? [];
      $size = $data['size'] ?? static::MAX_PAGINATION_SIZE;

      // Build the Elasticsearch query with the provided filters and sorts.
      $query = $this->buildQuery($filters, $sorts, $size);

      /** @var ElasticsearchService $elasticSearchServer */
      $elasticSearchService = ComponentBasedObject::getRootComponentByClassName(
        ElasticsearchService::class,
        TRUE
      );

      /** @var ErrorsIndexDef $errorIndex */
      $errorIndex = ComponentBasedObject::getRootComponentByClassName(ErrorsIndexDef::class, TRUE);

      $response = $elasticSearchService->search($errorIndex, $query);

      $results = $this->parseElasticSearchResponse($response);

      $output = $fullYamlServer;
      $output['data'] = $data;
      $output['data']['results'] = $results;

      $pathsQuery = $this->buildDistinctPathQuery();
      $response = $elasticSearchService->search($errorIndex, $pathsQuery);
      $paths = $this->parseDistinctPathResponse($response);
      $output['data']['paths'] = $paths;
      $tempStoreFactory = \Drupal::service('tempstore.private');

      $tempstore = $tempStoreFactory->get('wsolution');

      $tempstore->set(self::TEMP_STORE_KEY, $output);
    //  Response::sendOk($output);
    }
    catch (\Exception $e) {
      Response::sendInternalServerError();
    }
  }

}
