<?php

namespace Drupal\wsolution\PasseplatForms\Handler;

use PassePlat\Forms\Exception\WebServiceException;
use Symfony\Component\HttpFoundation\File\File;
use Symfony\Component\Yaml\Yaml;

trait HandlerTrait {

  /**
   * Get the blueprint yaml inside vendor.
   *
   * @param string $filename
   *   The yaml file name.
   *
   * @return mixed
   * @throws \Exception
   */
  public function getBlueprint(string $filename): mixed {
    // Get the absolute path of the YAML file.
    $file = new File('vendor://ea-lab/passeplat/passeplat-forms/blueprint/' . $filename . '.yaml');
    $content = $file->getContent();

    if (!$content) {
      throw new \Exception('Invalid YAML file path.');
    }

    $path = [
      '/build/navbar.php',
      '/build/dashboard.php',
      '/build/errors.php',
      '/build/logs.php',
      '/build/logs-details.php',
      '/build/webservices.php',
      '/build/webservice-edit.php',
    ];
    $new_path = [
      '/admin/structure/wsolution/navbar',
      '/admin/structure/wsolution/dashboard',
      '/admin/structure/wsolution/errors',
      '/admin/structure/wsolution/logs',
      '/admin/structure/wsolution/logs-details',
      '/admin/structure/wsolution/webservices',
      '/admin/structure/wsolution/webservice-edit',
    ];
    // Rewrite route.
    $content = str_replace($path, $new_path, $content);
    $path = [
      '/forms/navbar.php',
      '/forms/dump.php',
      '/forms/dashboard.php',
      '/forms/errors.php',
      '/forms/logs.php',
      '/forms/logs-details.php',
      '/forms/webservicesList.php',
      '/forms/webservices-edit.php',
    ];
    $new_path = [
      '/admin/structure/wsolution/handler/navbar',
      '/admin/structure/wsolution/handler/dump',
      '/admin/structure/wsolution/handler/dashboard',
      '/admin/structure/wsolution/handler/errors',
      '/admin/structure/wsolution/handler/logs',
      '/admin/structure/wsolution/handler/logs-details',
      '/admin/structure/wsolution/handler/webservices',
      '/admin/structure/wsolution/handler/webservice-edit',
    ];
    // Rewrite route.
    $content = str_replace($path, $new_path, $content);
    return Yaml::parse($content);
  }

  /**
   * Retrieves the list of webservices.
   *
   * @return array
   *   The webservices list.
   *
   * @throws WebServiceException
   *   Thrown if there are any issues encountered at the PassePlat webservice
   *   level.
   */
  protected function getWebServicesList(bool $export_array = TRUE): array {
    $webservices = [];
    /** @var  $wsolution_manager  \Drupal\wsolution\Services\WSolution */
    $wsolution_manager = \Drupal::service('wsolution.manager');
    /** @var  $wsolution_webservices  \Drupal\wsolution\Entity\WsolutionWebservice[] */
    $wsolution_webservices = \Drupal::entityTypeManager()
      ->getStorage('wsolution_webservice')
      ->loadMultiple();
    foreach ($wsolution_webservices as $webservice) {
      if (empty($webservice->get('domain'))) {
        continue;
      }
      $wsid = $wsolution_manager->transformDomainToWsid($webservice->get('domain'), $webservice->get('wsuid'));
      if ($export_array) {
        $webservices[$wsid] = $webservice->toArray();
        $webservices[$wsid]['wsid'] = $wsid;
        if (!empty($webservices[$wsid]['label'])) {
          $webservices[$wsid]['name'] = $webservices[$wsid]['label'];
        }
        continue;
      }
      $webservices[$wsid] = $webservice;
    }

    return $webservices;
  }

  /**
   * Get php input and json decode it.
   *
   * @return mixed
   */
  protected function getPhpInput() {
    return json_decode(file_get_contents('php://input'), TRUE);
  }

}
