<?php

namespace Drupal\wsolution\PasseplatForms\Handler;

use Dakwamine\Component\ComponentBasedObject;
use Drupal\wsolution_elastic\PasseplatElastic\Service\DrupalElasticsearchService;
use PassePlat\Forms\Vue\Response;
use Drupal\wsolution_elastic\PasseplatElastic\Definitions\AnalyzableContentIndexDef;
use PassePlat\Logger\Elastic\Service\ElasticsearchService;
use PassePlat\Forms\Handler\LogsDetailsHandler as BaseLogsDetailsHandler;

/**
 * Handles the processing of detailed log information for the log page's
 * details modal.
 */
class LogsDetailsHandler extends BaseLogsDetailsHandler {

  public const string TEMP_STORE_KEY = 'logs_details';
  use HandlerTrait;
  public function handlePostRequest(): void {
    try {
      $fullYamlServer = $this->getBlueprint('logs');
      $clientInput = $this->getPhpInput();
      $data = array_replace_recursive($fullYamlServer['data'], $clientInput['data'] ?? []);

      // Build the Elasticsearch query with the provided filters and sorts.
      $query = $this->buildQuery($data['details']['id']);

      /** @var ElasticsearchService $elasticSearchServer */
      $elasticSearchService = ComponentBasedObject::getRootComponentByClassName(
        DrupalElasticsearchService::class,
        TRUE
      );

      /** @var AnalyzableContentIndexDef $analyzableContentIndex */
      $analyzableContentIndex = ComponentBasedObject::getRootComponentByClassName(
        AnalyzableContentIndexDef::class,
        TRUE
      );

      $response = $elasticSearchService->search($analyzableContentIndex, $query);

      $details = $this->parseElasticSearchResponse($response);

      $output = $fullYamlServer;
      $output['data'] = $data;

      $output['data']['details']['initiator_request_headers'] = $details['initiator_request_headers'];
      $output['data']['details']['initiator_request_body'] = $details['initiator_request_body'];
      $output['data']['details']['destination_response_headers'] =
        $details['destination_response_headers'];
      $output['data']['details']['destination_response_body'] = $details['destination_response_body'];
      $tempStoreFactory = \Drupal::service('tempstore.private');

      $tempstore = $tempStoreFactory->get('wsolution');

      $tempstore->set(self::TEMP_STORE_KEY, $output);
    //  Response::sendOk($output);
    }
    catch (\Exception $e) {
      Response::sendInternalServerError();
    }
  }

}
