<?php

namespace Drupal\wsolution\PasseplatForms\Handler;

use Dakwamine\Component\ComponentBasedObject;
use Drupal\wsolution_elastic\PasseplatElastic\Service\DrupalElasticsearchService;
use PassePlat\Forms\Vue\Response;
use Drupal\wsolution_elastic\PasseplatElastic\Definitions\AnalyzableContentIndexDef;
use PassePlat\Logger\Elastic\Service\ElasticsearchService;
use PassePlat\Forms\Handler\LogsHandler as BaseLogsHandler;

/**
 * Provides methods for performing specific operations related to logs page.
 */
class LogsHandler extends BaseLogsHandler {

  public const string TEMP_STORE_KEY = 'logs';
  use HandlerTrait;

  public function handlePostRequest(): void {
    try {
      $fullYamlServer = $this->getBlueprint('logs');
      $clientInput = $this->getPhpInput();
      if (!empty($clientInput['data'])) {
        // The user clicked on the button.
        $data = $clientInput['data'];
      }

      // Set the filters, pagination, and sort parameters.
      $filters = $data['filters'];

      $size = $data['size'] ?? static::MAX_PAGINATION_SIZE;
      $from = $data['from'] ?? 0;

      // Build the Elasticsearch query with the provided filters and sorts.
      $query = $this->buildQuery($filters, $from, $size);

      /** @var ElasticsearchService $elasticSearchServer */
      $elasticSearchService = ComponentBasedObject::getRootComponentByClassName(
        DrupalElasticsearchService::class,
        TRUE
      );

      /** @var AnalyzableContentIndexDef $analyzableContentIndex */
      $analyzableContentIndex = ComponentBasedObject::getRootComponentByClassName(
        AnalyzableContentIndexDef::class,
        TRUE
      );

      $response = $elasticSearchService->search($analyzableContentIndex, $query);

      $results = $this->parseElasticSearchResponse($response);

      $output = $fullYamlServer;
      $output['data'] = $data;
      $output['data']['results'] = $results;
      $tempStoreFactory = \Drupal::service('tempstore.private');

      $tempstore = $tempStoreFactory->get('wsolution');

      $tempstore->set(self::TEMP_STORE_KEY, $results);
     // Response::sendOk($output);
    }
    catch (\Exception $e) {
      Response::sendInternalServerError();
    }
  }


}
