<?php

namespace Drupal\wsolution\PasseplatForms\Handler;

use PassePlat\Forms\Exception\WebServiceException;
use PassePlat\Forms\Vue\Response;
use PassePlat\Forms\Handler\NavbarHandler as BaseNavbarHandler;

class NavbarHandler extends BaseNavbarHandler {

  public const string TEMP_STORE_KEY = 'navbar';
  use HandlerTrait;

  /**
   * Retrieves the cached list of web services, updating it if necessary.
   *
   * @return array
   *   The list of web services.
   *
   * @throws WebServiceException
   *   Thrown if there are any issues encountered at the PassePlat webservice
   *   level.
   */
  protected function getWebServices(): array {
    if (empty($this->webservices)) {
      $this->webservices = $this->getWebServicesList();
    }

    return $this->webservices;
  }

  public function handlePostRequest(): void {
    try {
      $request = \Drupal::request();
      $wsid = $request->query->get('wsid') ?? '';
      $activeTab = $request->query->get('activeTab') ?? '';
      $locked = empty($wsid) || !in_array($activeTab, [
          'dashboard',
          'errors',
          'logs',
          'edit',
        ], TRUE);

      $yamContent = $this->getBlueprint('navbar');

      if (!$locked) {
        $this->setHrefs($yamContent, $wsid);
        $yamContent['data']['locked'] = FALSE;
      }

      $this->setWebServices($yamContent, $wsid, $locked);
      $tempStoreFactory = \Drupal::service('tempstore.private');

      $tempstore = $tempStoreFactory->get('wsolution');

      $tempstore->set(self::TEMP_STORE_KEY, $yamContent);
      //  Response::sendOk($yamContent);
    }
    catch (\Exception $e) {
      Response::sendInternalServerError();
    }
  }

  /**
   * Populates the result array with the list of available web services.
   *
   * @param array $result
   *   Reference to the result array to populate.
   * @param string $wsid
   *   The selected web service ID.
   * @param bool $locked
   *   Whether the right side of the navbar is locked.
   *
   * @throws WebServiceException
   *   Thrown if there are any issues encountered at the PassePlat webservice
   *   level.
   */
  private function setWebServices(array &$result, string $wsid, bool $locked) {
    $this->getWebServices();
    $formattedWebServices[] = [
      'label' => t('-- List of my webservices --'),
      'value' => ($locked || empty($wsid)) ? 'All' : '/admin/structure/wsolution/webservices',
    ];
    /** @var  $wsolution_manager \Drupal\wsolution\Services\WSolution */
    $wsolution_manager = \Drupal::service('wsolution.manager');

    foreach ($this->webservices as $webservice) {
      if (empty($webservice['domain'])) {
        continue;
      }
      $webservice_id = $wsolution_manager->transformDomainToWsid($webservice['domain'], $webservice['wsuid'] ?? '');
      $formattedWebServices[] = [
        'label' => $webservice['label'] ?? t('undefined title'),
        'value' => ($webservice_id === $wsid) ? 'All' : '/admin/structure/wsolution/dashboard?wsid=' . $webservice_id,
      ];
    }

    $result['data']['webservices'] = $formattedWebServices;
    $result['data']['selectedWebservice'] = 'All';
  }

}
