<?php

namespace Drupal\wsolution\PasseplatForms\Handler;

use PassePlat\Forms\Exception\ConditionException;
use PassePlat\Forms\Exception\WebServiceException;
use PassePlat\Forms\Handler\WebServiceEdit;
use PassePlat\Forms\Vue\Response;

class WebServiceEditHandler extends WebServiceEdit {

  public const string TEMP_STORE_KEY = 'webservice_edit';
  use HandlerTrait;

  /**
   * Retrieves the list of webservices.
   *
   * @return array
   *   The webservices list.
   *
   * @throws WebServiceException
   *   Thrown if there are any issues encountered at the PassePlat webservice
   *   level.
   */
  protected function getWebServices(): array {
    if (empty($this->webservices)) {
      $this->webservices = $this->getWebServicesList();
    }

    return $this->webservices;
  }
  /**
   * Retrieves a list of condition qualified classes.
   *
   * @return array
   *   Array of condition classes.
   *
   * @throws ConditionException
   *   If there is an issue retrieving the conditions.
   */
  public function handlePostRequest(): void {
    try {
      $wsid = \Drupal::request()->query->get('wsid') ?? NULL;
      $result = $this->getBlueprint('edit');

      $result['data']['mostRecentTasks'] = $this->mostRecentTasks();
      $result['data']['selectedTaskToAdd'] = $this->mostRecentTasks['Fallback']['class'];
      $result['data']['mostRecentConditions'] = $this->mostRecentConditions();
      $result['data']['selectedConditionToAdd'] = $this->mostRecentConditions['EndpointCondition']['class'];

      $this->setInfos($result, $wsid);
      $this->setTasks($result, $wsid);
      $this->setConditions($result, $wsid);
      $tempStoreFactory = \Drupal::service('tempstore.private');

      $tempstore = $tempStoreFactory->get('wsolution');

      $tempstore->set(self::TEMP_STORE_KEY, $result);
    //  Response::sendOk($result);
    }
    catch (\Exception $e) {
      Response::sendInternalServerError();
    }
  }
  protected function getAllConditions(): array
  {
    try {
      $conditionFiles = scandir('vendor://ea-lab/passeplat/passeplat-core/src/StreamProcessor/SchemeProcessor/Task/Condition');

      if ($conditionFiles === false) {
        throw new ConditionException('Directory of conditions not found');
      }

      return array_filter(
        array_map(fn($conditionFile) => $this->processConditionFile($conditionFile), $conditionFiles)
      );
    } catch (ConditionException $e) {
      throw $e;
    } catch (\Exception $e) {
      throw new ConditionException($e->getMessage());
    }
  }

}
